@@ -26,6 +26,7 @@
 #include "gui/iconfont.h"
 #include "gui/iconwidget.h"
 #include "gui/pixelratio.h"
+#include "item/itemfilter.h"
 
 #include <QBoxLayout>
 #include <QLabel>
@@ -146,8 +147,6 @@ void ItemNotes::setCurrent(bool current)
 
     m_isCurrent = current;
 
-    ItemWidget::setCurrent(current);
-
     if (m_timerShowToolTip == nullptr)
         return;
 
@@ -159,46 +158,6 @@ void ItemNotes::setCurrent(bool current)
         m_timerShowToolTip->stop();
 }
 
-void ItemNotes::highlight(const QRegularExpression &re, const QFont &highlightFont, const QPalette &highlightPalette)
-{
-    ItemWidgetWrapper::highlight(re, highlightFont, highlightPalette);
-
-    if (m_notes != nullptr) {
-        QList<QTextEdit::ExtraSelection> selections;
-
-        if ( re.isValid() && !re.pattern().isEmpty() ) {
-            QTextEdit::ExtraSelection selection;
-            selection.format.setBackground( highlightPalette.base() );
-            selection.format.setForeground( highlightPalette.text() );
-            selection.format.setFont(highlightFont);
-
-            QTextCursor cur = m_notes->document()->find(re);
-            int a = cur.position();
-            while ( !cur.isNull() ) {
-                if ( cur.hasSelection() ) {
-                    selection.cursor = cur;
-                    selections.append(selection);
-                } else {
-                    cur.movePosition(QTextCursor::NextCharacter);
-                }
-                cur = m_notes->document()->find(re, cur);
-                int b = cur.position();
-                if (a == b) {
-                    cur.movePosition(QTextCursor::NextCharacter);
-                    cur = m_notes->document()->find(re, cur);
-                    b = cur.position();
-                    if (a == b) break;
-                }
-                a = b;
-            }
-        }
-
-        m_notes->setExtraSelections(selections);
-    }
-
-    update();
-}
-
 void ItemNotes::updateSize(QSize maximumSize, int idealWidth)
 {
     setMaximumSize(maximumSize);
@@ -313,8 +272,8 @@ ItemWidget *ItemNotesLoader::transform(ItemWidget *itemWidget, const QVariantMap
         m_settings["show_tooltip"].toBool() );
 }
 
-bool ItemNotesLoader::matches(const QModelIndex &index, const QRegularExpression &re) const
+bool ItemNotesLoader::matches(const QModelIndex &index, const ItemFilter &filter) const
 {
     const QString text = index.data(contentType::notes).toString();
-    return text.contains(re);
+    return filter.matches(text);
 }
