@@ -50,6 +50,7 @@
 #include <QMessageBox>
 #include <QMimeData>
 #include <QSessionManager>
+#include <QStyleFactory>
 #include <QTextEdit>
 
 #ifdef NO_GLOBAL_SHORTCUTS
@@ -115,8 +116,10 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
         COPYQ_LOG("Server \"" + serverName + "\" started.");
     } else {
         restoreSettings(false);
-        COPYQ_LOG("Server \"" + serverName + "\" already running!");
-        log( tr("CopyQ server is already running."), LogWarning );
+        if ( canUseStandardOutput() ) {
+            COPYQ_LOG("Server \"" + serverName + "\" already running!");
+            log( tr("CopyQ server is already running."), LogWarning );
+        }
         exit(0);
         return;
     }
@@ -125,7 +128,7 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
         QGuiApplication::setApplicationDisplayName("CopyQ");
     } else {
         QGuiApplication::setApplicationDisplayName(
-            QString("CopyQ-%1").arg(sessionName));
+            QString::fromLatin1("CopyQ-%1").arg(sessionName));
     }
 
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
@@ -188,6 +191,8 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
         m_actionDataToSend.clear();
     });
 
+    initSingleShotTimer(&m_updateThemeTimer, 1000, this, &ClipboardServer::loadSettings);
+
     startMonitoring();
 
     callback("onStart");
@@ -326,8 +331,6 @@ void ClipboardServer::onSaveState(QSessionManager &sessionManager)
 
     const QString lastSessionIdPrefix = "last_session_id_for_";
     const auto lastSessionIdKey = lastSessionIdPrefix + sessionName;
-    const auto lastSessionId = settings.value(lastSessionIdKey).toString();
-    const auto lastSessionNameKey = "session_" + lastSessionId;
     settings.setValue(lastSessionIdKey, sessionNameKey);
 
     // Remove no longer valid sessions from configuration.
@@ -464,40 +467,6 @@ void ClipboardServer::sendActionData(int actionId, const QByteArray &bytes)
     }
 }
 
-void ClipboardServer::updateNotifications()
-{
-    if (!m_sharedData->notifications)
-        return;
-
-    m_sharedData->notifications->setNotificationOpacity(
-        m_sharedData->theme.color("notification_bg").alphaF() );
-    m_sharedData->notifications->setNotificationStyleSheet(
-        m_sharedData->theme.getNotificationStyleSheet() );
-
-    AppConfig appConfig;
-    int id = appConfig.option<Config::notification_position>();
-    NotificationDaemon::Position position;
-    switch (id) {
-    case 0: position = NotificationDaemon::Top; break;
-    case 1: position = NotificationDaemon::Bottom; break;
-    case 2: position = NotificationDaemon::TopRight; break;
-    case 3: position = NotificationDaemon::BottomRight; break;
-    case 4: position = NotificationDaemon::BottomLeft; break;
-    default: position = NotificationDaemon::TopLeft; break;
-    }
-    m_sharedData->notifications->setPosition(position);
-
-    const int x = appConfig.option<Config::notification_horizontal_offset>();
-    const int y = appConfig.option<Config::notification_vertical_offset>();
-    m_sharedData->notifications->setOffset(x, y);
-
-    const int w = appConfig.option<Config::notification_maximum_width>();
-    const int h = appConfig.option<Config::notification_maximum_height>();
-    m_sharedData->notifications->setMaximumSize(w, h);
-
-    m_sharedData->notifications->updateNotifications();
-}
-
 void ClipboardServer::onClientNewConnection(const ClientSocketPtr &client)
 {
     auto proxy = new ScriptableProxy(m_wnd);
@@ -591,8 +560,8 @@ void ClipboardServer::onNotificationButtonClicked(const NotificationButton &butt
 void ClipboardServer::createGlobalShortcut(const QKeySequence &shortcut, const Command &command)
 {
 #ifdef NO_GLOBAL_SHORTCUTS
-    Q_UNUSED(shortcut);
-    Q_UNUSED(command);
+    Q_UNUSED(shortcut)
+    Q_UNUSED(command)
 #else
     auto s = new QxtGlobalShortcut(shortcut, this);
     if (!s->isValid()) {
@@ -639,9 +608,10 @@ bool ClipboardServer::eventFilter(QObject *object, QEvent *ev)
             }
         // Omit overriding arrow keys in text editors.
         } else if ( type == QEvent::ShortcutOverride &&
-                    object->property("textInteractionFlags")
-                    .value<Qt::TextInteractionFlags>()
-                    .testFlag(Qt::TextSelectableByKeyboard) )
+                    (object->metaObject()->className() == QLatin1String("QLineEdit")
+                     || object->property("textInteractionFlags")
+                        .value<Qt::TextInteractionFlags>()
+                        .testFlag(Qt::TextSelectableByKeyboard)) )
         {
             QKeyEvent *keyevent = static_cast<QKeyEvent *>(ev);
             if ( keyevent->key() == Qt::Key_Left
@@ -666,6 +636,10 @@ bool ClipboardServer::eventFilter(QObject *object, QEvent *ev)
             COPYQ_LOG( QString("Saving items on application state change (%1)").arg(state) );
             m_wnd->saveTabs();
         }
+    } else if (type == QEvent::ThemeChange) {
+        if ( !m_updateThemeTimer.isActive() )
+            COPYQ_LOG("Got theme change event");
+        m_updateThemeTimer.start();
     }
 
     return false;
@@ -682,11 +656,24 @@ void ClipboardServer::loadSettings()
 
     m_sharedData->itemFactory->loadItemFactorySettings(&settings);
 
+    AppConfig appConfig;
+
+    const QString styleName = appConfig.option<Config::style>();
+    if ( !styleName.isEmpty() ) {
+        log( QString("Style: %1").arg(styleName) );
+        QStyle *style = QStyleFactory::create(styleName);
+        if (style) {
+            QApplication::setStyle(style);
+        } else {
+            const QString styles = QStyleFactory::keys().join(", ");
+            log( QString("Failed to set style, valid are: %1").arg(styles), LogWarning );
+        }
+    }
+
     settings.beginGroup("Theme");
     m_sharedData->theme.loadTheme(settings);
     settings.endGroup();
 
-    AppConfig appConfig;
     m_sharedData->editor = appConfig.option<Config::editor>();
     m_sharedData->maxItems = appConfig.option<Config::maxitems>();
     m_sharedData->textWrap = appConfig.option<Config::text_wrap>();
@@ -701,6 +688,7 @@ void ClipboardServer::loadSettings()
     m_sharedData->saveDelayMsOnItemRemoved = appConfig.option<Config::save_delay_ms_on_item_removed>();
     m_sharedData->saveDelayMsOnItemMoved = appConfig.option<Config::save_delay_ms_on_item_moved>();
     m_sharedData->saveDelayMsOnItemEdited = appConfig.option<Config::save_delay_ms_on_item_edited>();
+    m_sharedData->rowIndexFromOne = appConfig.option<Config::row_index_from_one>();
 
     m_wnd->loadSettings(settings, appConfig);
 
@@ -712,7 +700,7 @@ void ClipboardServer::loadSettings()
         startMonitoring();
     }
 
-    updateNotifications();
+    m_updateThemeTimer.stop();
 
     COPYQ_LOG("Configuration loaded");
 }
@@ -720,7 +708,7 @@ void ClipboardServer::loadSettings()
 void ClipboardServer::shortcutActivated(QxtGlobalShortcut *shortcut)
 {
 #ifdef NO_GLOBAL_SHORTCUTS
-    Q_UNUSED(shortcut);
+    Q_UNUSED(shortcut)
 #else
     m_ignoreKeysTimer.start();
 
