@@ -72,19 +72,18 @@ ActionDialog::ActionDialog(QWidget *parent)
 {
     ui->setupUi(this);
     ui->comboBoxCommands->setFont( ui->commandEdit->commandFont() );
-    ui->commandEdit->setFocus();
 
-    auto shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_P), this);
+    auto shortcut = new QShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_P), this);
     connect(shortcut, &QShortcut::activated, this, &ActionDialog::previousCommand);
-    shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_N), this);
+    shortcut = new QShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_N), this);
     connect(shortcut, &QShortcut::activated, this, &ActionDialog::nextCommand);
 
     connect(ui->buttonBox, &QDialogButtonBox::clicked,
             this, &ActionDialog::onButtonBoxClicked);
     connect(ui->comboBoxCommands, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
             this, &ActionDialog::onComboBoxCommandsCurrentIndexChanged);
-    connect(ui->comboBoxInputFormat, static_cast<void (QComboBox::*)(const QString&)>(&QComboBox::currentIndexChanged),
-            this, &ActionDialog::onComboBoxInputFormatCurrentIndexChanged);
+    connect(ui->comboBoxInputFormat, &QComboBox::currentTextChanged,
+            this, &ActionDialog::onComboBoxInputFormatCurrentTextChanged);
     connect(ui->comboBoxOutputFormat, &QComboBox::editTextChanged,
             this, &ActionDialog::onComboBoxOutputFormatEditTextchanged);
     connect(ui->comboBoxOutputTab, &QComboBox::editTextChanged,
@@ -92,7 +91,7 @@ ActionDialog::ActionDialog(QWidget *parent)
     connect(ui->separatorEdit, &QLineEdit::textEdited,
             this, &ActionDialog::onSeparatorEditTextEdited);
 
-    onComboBoxInputFormatCurrentIndexChanged(QString());
+    onComboBoxInputFormatCurrentTextChanged(QString());
     onComboBoxOutputFormatEditTextchanged(QString());
     loadSettings();
 }
@@ -135,7 +134,7 @@ void ActionDialog::restoreHistory()
 
 const QString ActionDialog::dataFilename() const
 {
-    return getConfigurationFilePath( QString("_cmds.dat") );
+    return getConfigurationFilePath("_cmds.dat");
 }
 
 void ActionDialog::saveHistory()
@@ -265,7 +264,7 @@ void ActionDialog::onComboBoxCommandsCurrentIndexChanged(int index)
         ui->comboBoxOutputTab->setEditText(values.value(outputTab).toString());
 }
 
-void ActionDialog::onComboBoxInputFormatCurrentIndexChanged(const QString &format)
+void ActionDialog::onComboBoxInputFormatCurrentTextChanged(const QString &format)
 {
     setChangedByUser(ui->comboBoxInputFormat);
 
@@ -328,7 +327,7 @@ void ActionDialog::acceptCommand()
     if ( ui->inputText->isVisible() )
         m_data[mimeText] = ui->inputText->toPlainText();
 
-    emit accepted(command, capturedTexts, m_data);
+    emit commandAccepted(command, capturedTexts, m_data);
 }
 
 QVariant ActionDialog::createCurrentItemData()
