@@ -32,8 +32,9 @@
 #include "gui/iconfont.h"
 #include "gui/pixelratio.h"
 #include "gui/theme.h"
-#include "item/itemeditor.h"
 #include "item/itemdelegate.h"
+#include "item/itemeditor.h"
+#include "item/itemfilter.h"
 
 #include <QAbstractScrollArea>
 #include <QAction>
@@ -44,8 +45,47 @@
 #include <QPainter>
 #include <QScrollBar>
 #include <QSettings>
+#include <QTextCursor>
+#include <QTextDocument>
+#include <QTextEdit>
 #include <QTemporaryFile>
 
+#include <memory>
+
+namespace {
+
+class ItemFilterSimple final : public ItemFilter {
+public:
+    explicit ItemFilterSimple(const QString &text) noexcept
+        : m_text(text)
+    {
+    }
+
+    QString searchString() const override { return m_text; }
+    bool matchesAll() const override { return false; }
+    bool matchesNone() const override { return false; }
+    bool matches(const QString &) const override { return true; }
+    bool matchesIndex(const QModelIndex &) const override { return true; }
+
+    void highlight(QTextEdit *edit, const QTextCharFormat &format) const override
+    {
+        QTextCursor cur = edit->document()->find(m_text);
+        if ( !cur.hasSelection() )
+            return;
+
+        QTextEdit::ExtraSelection selection{cur, format};
+        edit->setExtraSelections({selection});
+        edit->update();
+    }
+
+    void search(QTextEdit *, bool) const override {}
+
+private:
+    QString m_text;
+};
+
+} // namespace
+
 ConfigTabAppearance::ConfigTabAppearance(QWidget *parent)
     : QWidget(parent)
     , ui(new Ui::ConfigTabAppearance)
@@ -70,7 +110,11 @@ ConfigTabAppearance::ConfigTabAppearance(QWidget *parent)
     connect(ui->checkBoxAntialias, &QCheckBox::stateChanged,
             this, &ConfigTabAppearance::onCheckBoxAntialiasStateChanged);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+    connect(ui->comboBoxThemes, &QComboBox::textActivated,
+#else
     connect(ui->comboBoxThemes, static_cast<void (QComboBox::*)(const QString&)>(&QComboBox::activated),
+#endif
             this, &ConfigTabAppearance::onComboBoxThemesActivated);
 
     // Connect signals from theme buttons.
@@ -132,7 +176,7 @@ void ConfigTabAppearance::onColorButtonClicked()
 void ConfigTabAppearance::onPushButtonLoadThemeClicked()
 {
     const QString filename = QFileDialog::getOpenFileName(this, tr("Open Theme File"),
-                                                          defaultUserThemePath(), QString("*.ini"));
+                                                          defaultUserThemePath(), QLatin1String("*.ini"));
     if ( !filename.isNull() ) {
         QSettings settings(filename, QSettings::IniFormat);
         loadTheme(settings);
@@ -142,7 +186,7 @@ void ConfigTabAppearance::onPushButtonLoadThemeClicked()
 void ConfigTabAppearance::onPushButtonSaveThemeClicked()
 {
     QString filename = QFileDialog::getSaveFileName(this, tr("Save Theme File As"),
-                                                    defaultUserThemePath(), QString("*.ini"));
+                                                    defaultUserThemePath(), QLatin1String("*.ini"));
     if ( !filename.isNull() ) {
         if ( !filename.endsWith(".ini") )
             filename.append(".ini");
@@ -452,17 +496,17 @@ void ConfigTabAppearance::decoratePreview()
     model->setData(index, dataMap, contentType::updateData);
 
     // Highlight found text but don't filter out any items.
-    c->filterItems( QRegularExpression(QString("^|") + searchFor, QRegularExpression::CaseInsensitiveOption) );
+    c->filterItems(std::make_shared<ItemFilterSimple>(searchFor));
 
     QAction *act;
 
     act = new QAction(c);
-    act->setShortcut( QString("Shift+F2") );
+    act->setShortcut( QKeySequence(QLatin1String("Shift+F2")) );
     connect(act, &QAction::triggered, c, &ClipboardBrowser::editNotes);
     c->addAction(act);
 
     act = new QAction(c);
-    act->setShortcut( QString("F2") );
+    act->setShortcut( QKeySequence(QLatin1String("F2")) );
     connect(act, &QAction::triggered, c, &ClipboardBrowser::editSelected);
     c->addAction(act);
 }
