@@ -369,6 +369,8 @@ public:
     void setClipboardAndSelection(const QVariantMap &data);
     void moveToClipboard(ClipboardBrowser *c, int row);
 
+    const QMimeData *getClipboardData(ClipboardMode mode);
+
     /** Show/hide main window. Return true only if window is shown. */
     bool toggleVisible();
 
@@ -461,7 +463,7 @@ private:
     void tabBarMenuRequested(QPoint pos, int tab);
     void tabTreeMenuRequested(QPoint pos, const QString &groupPath);
     void tabCloseRequested(int tab);
-    void onFilterChanged(const QRegularExpression &re);
+    void onFilterChanged();
 
     void raiseLastWindowAfterMenuClosed();
 
@@ -666,13 +668,13 @@ private:
 
     QTimer m_timerUpdateFocusWindows;
     QTimer m_timerUpdateContextMenu;
-    QTimer m_timerUpdateTrayMenuItems;
     QTimer m_timerUpdatePreview;
-    QTimer m_timerTrayAvailable;
     QTimer m_timerSaveTabPositions;
     QTimer m_timerHideWindowIfNotActive;
     QTimer m_timerRaiseLastWindowAfterMenuClosed;
 
+    bool m_trayMenuDirty = true;
+
     QVariantMap m_clipboardData;
 
     TrayMenu *m_menu;
