@@ -25,6 +25,8 @@ int screenNumberAt(const QPoint &pos)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5,11,0)
     auto screen = QGuiApplication::screenAt(pos);
+    if (screen == nullptr)
+        screen = QGuiApplication::primaryScreen();
     return QGuiApplication::screens().indexOf(screen);
 #else
     return QApplication::desktop()->screenNumber(pos);
@@ -45,7 +47,15 @@ QRect screenAvailableGeometry(const QPoint &pos)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5,11,0)
     auto screen = QGuiApplication::screenAt(pos);
-    return screen ? screen->availableGeometry() : screenGeometry(0);
+    if (screen == nullptr) {
+        screen = screenFromNumber(0);
+        if (screen == nullptr)
+            return QRect();
+    }
+
+    const QRect g = screen->availableGeometry();
+    const qreal ratio = screen->devicePixelRatio();
+    return QRect(g.topLeft() * ratio, g.bottomRight() * ratio);
 #else
     return QApplication::desktop()->availableGeometry(pos);
 #endif
