@@ -37,22 +37,77 @@
 
 namespace {
 
+const QLatin1String defaultColorVarBase("default_bg");
+const QLatin1String defaultColorVarText("default_text");
+const QLatin1String defaultColorVarPlaceholderText("default_placeholder_text");
+const QLatin1String defaultColorVarAlternateBase("default_alt_bg");
+const QLatin1String defaultColorVarHighlight("default_highlight_bg");
+const QLatin1String defaultColorVarHighlightText("default_highlight_text");
+const QLatin1String defaultColorVarToolTipBase("default_tooltip_bg");
+const QLatin1String defaultColorVarToolTipText("default_tooltip_text");
+const QLatin1String defaultColorVarWindow("default_window");
+const QLatin1String defaultColorVarWindowText("default_window_text");
+const QLatin1String defaultColorVarButton("default_button");
+const QLatin1String defaultColorVarButtonText("default_button_text");
+const QLatin1String defaultColorVarBrightText("default_bright_text");
+const QLatin1String defaultColorVarLight("default_light");
+const QLatin1String defaultColorVarMidlight("default_midlight");
+const QLatin1String defaultColorVarDark("default_dark");
+const QLatin1String defaultColorVarMid("default_mid");
+const QLatin1String defaultColorVarShadow("default_shadow");
+const QLatin1String defaultColorLink("default_link");
+const QLatin1String defaultColorLinkVisited("default_link_visited");
+
+QPalette::ColorRole defaultColorVarToRole(const QString &varName)
+{
+    static QHash<QString, QPalette::ColorRole> map = {
+        {defaultColorVarBase, QPalette::Base},
+        {defaultColorVarText, QPalette::Text},
+#if QT_VERSION >= QT_VERSION_CHECK(5,12,0)
+        {defaultColorVarPlaceholderText, QPalette::PlaceholderText},
+#else
+        {defaultColorVarPlaceholderText, QPalette::AlternateBase},
+#endif
+        {defaultColorVarAlternateBase, QPalette::AlternateBase},
+        {defaultColorVarHighlight, QPalette::Highlight},
+        {defaultColorVarHighlightText, QPalette::HighlightedText},
+        {defaultColorVarToolTipBase, QPalette::ToolTipBase},
+        {defaultColorVarToolTipText, QPalette::ToolTipText},
+        {defaultColorVarWindow, QPalette::Window},
+        {defaultColorVarWindowText, QPalette::WindowText},
+        {defaultColorVarButton, QPalette::Button},
+        {defaultColorVarButtonText, QPalette::ButtonText},
+        {defaultColorVarBrightText, QPalette::BrightText},
+        {defaultColorVarLight, QPalette::Light},
+        {defaultColorVarMidlight, QPalette::Midlight},
+        {defaultColorVarDark, QPalette::Dark},
+        {defaultColorVarMid, QPalette::Mid},
+        {defaultColorVarShadow, QPalette::Shadow},
+        {defaultColorLink, QPalette::Link},
+        {defaultColorLinkVisited, QPalette::LinkVisited},
+    };
+    const auto it = map.find(varName);
+    return (it == std::end(map)) ? QPalette::NoRole : it.value();
+}
+
 double normalizeFactor(double value)
 {
     return qBound( 0.0, value, 1.0 );
 }
 
-int normalizeColorValue(float value)
+int normalizeColorValue(int value)
 {
-    return qBound( 0, static_cast<int>(value), 255 );
+    return qBound(0, value, 255);
 }
 
 /// Add RGB components properly.
 int addColor(int c1, float multiply, int c2)
 {
+    const float f1 = static_cast<float>(c1);
+    const float f2 = static_cast<float>(c2);
     return multiply > 0.0f
-            ? static_cast<int>( std::sqrt(c1*c1 + multiply * c2*c2) )
-            : c1 + static_cast<int>(multiply * c2);
+            ? static_cast<int>( std::sqrt(f1*f1 + multiply * f2*f2) )
+            : c1 + static_cast<int>(multiply * f2);
 }
 
 void addColor(
@@ -75,6 +130,9 @@ void addColor(
         toAdd = deserializeColor(color);
         if ( !toAdd.isValid() )
             toAdd = QColor(Qt::black);
+    } else if ( color.startsWith(QStringLiteral("default_")) ) {
+        const QPalette::ColorRole role = defaultColorVarToRole(color);
+        toAdd = QPalette().color(role);
     } else if (maxRecursion > 0) {
         const QVariant v = values.contains(color)
                 ? values.value(color) : theme.value(color);
@@ -84,8 +142,11 @@ void addColor(
     *r = normalizeColorValue( addColor(*r, x, toAdd.red()) );
     *g = normalizeColorValue( addColor(*g, x, toAdd.green()) );
     *b = normalizeColorValue( addColor(*b, x, toAdd.blue()) );
-    if (multiply > 0.0f)
-        *a = normalizeColorValue(*a + x * toAdd.alpha());
+    if (multiply > 0.0f) {
+        const float fa = static_cast<float>(*a);
+        const float fad = static_cast<float>(toAdd.alpha());
+        *a = normalizeColorValue( static_cast<int>(fa + x * fad) );
+    }
 }
 
 int fitFontWeight(int weight, int low, int high, int highCss)
@@ -149,22 +210,22 @@ QString getFontStyleSheet(const QString &fontString, double scale = 1.0)
     size = qBound(0.1, size, 50.0);
 
     QString result;
-    result.append( QString(";font-family: \"%1\"").arg(font.family()) );
-    result.append( QString(";font:%1 %2 %3%4")
+    result.append( QString::fromLatin1(";font-family: \"%1\"").arg(font.family()) );
+    result.append( QString::fromLatin1(";font:%1 %2 %3%4")
                    .arg(font.style() == QFont::StyleItalic
                         ? "italic" : font.style() == QFont::StyleOblique ? "oblique" : "normal",
                         font.bold() ? "bold" : "")
                    .arg(size)
                    .arg(sizeUnits)
                    );
-    result.append( QString(";text-decoration:%1 %2 %3")
+    result.append( QString::fromLatin1(";text-decoration:%1 %2 %3")
                    .arg(font.strikeOut() ? "line-through" : "",
                         font.underline() ? "underline" : "",
                         font.overline() ? "overline" : "")
                    );
 
     const int w = getFontWeightForStyleSheet( font.weight() );
-    result.append( QString(";font-weight:%1").arg(w) );
+    result.append( QString::fromLatin1(";font-weight:%1").arg(w) );
 
     result.append(";");
 
@@ -209,10 +270,10 @@ void Theme::loadTheme(const QSettings &settings)
 {
     resetTheme();
 
-    for ( const auto &key : m_theme.keys() ) {
-        const auto value = settings.value(key);
+    for ( auto key = m_theme.keyBegin(); key != m_theme.keyEnd(); ++key ) {
+        const auto value = settings.value(*key);
         if ( value.isValid() )
-            m_theme[key].setValue(value);
+            m_theme[*key].setValue(value);
     }
 
     updateTheme();
@@ -303,12 +364,6 @@ QString Theme::getToolTipStyleSheet() const
     return getStyleSheet(cssTemplate);
 }
 
-QString Theme::getNotificationStyleSheet() const
-{
-    const QString cssTemplate = value("css_template_notification").toString();
-    return getStyleSheet(cssTemplate);
-}
-
 Qt::ScrollBarPolicy Theme::scrollbarPolicy() const
 {
     return value("show_scrollbars").toBool()
@@ -338,29 +393,18 @@ bool Theme::isAntialiasingEnabled() const
 
 void Theme::resetTheme()
 {
-    QString name;
-    QPalette p;
-    name = serializeColor( p.color(QPalette::Base) );
-    m_theme["bg"]          = Option(name, "VALUE", ui ? ui->pushButtonColorBg : nullptr);
-    m_theme["edit_bg"]     = Option(name, "VALUE", ui ? ui->pushButtonColorEditorBg : nullptr);
-    name = serializeColor( p.color(QPalette::Text) );
-    m_theme["fg"]          = Option(name, "VALUE", ui ? ui->pushButtonColorFg : nullptr);
-    m_theme["edit_fg"]     = Option(name, "VALUE", ui ? ui->pushButtonColorEditorFg : nullptr);
-    name = serializeColor( p.color(QPalette::Text).lighter(400) );
-    m_theme["num_fg"]      = Option(name, "VALUE", ui ? ui->pushButtonColorNumberFg : nullptr);
-    name = serializeColor( p.color(QPalette::AlternateBase) );
-    m_theme["alt_bg"]      = Option(name, "VALUE", ui ? ui->pushButtonColorAltBg : nullptr);
-    name = serializeColor( p.color(QPalette::Highlight) );
-    m_theme["sel_bg"]      = Option(name, "VALUE", ui ? ui->pushButtonColorSelBg : nullptr);
-    name = serializeColor( p.color(QPalette::HighlightedText) );
-    m_theme["sel_fg"]      = Option(name, "VALUE", ui ? ui->pushButtonColorSelFg : nullptr);
-    m_theme["find_bg"]     = Option("#ff0", "VALUE", ui ? ui->pushButtonColorFoundBg : nullptr);
-    m_theme["find_fg"]     = Option("#000", "VALUE", ui ? ui->pushButtonColorFoundFg : nullptr);
-    name = serializeColor( p.color(QPalette::ToolTipBase) );
-    m_theme["notes_bg"]  = Option(name, "VALUE", ui ? ui->pushButtonColorNotesBg : nullptr);
-    name = serializeColor( p.color(QPalette::ToolTipText) );
-    m_theme["notes_fg"]  = Option(name, "VALUE", ui ? ui->pushButtonColorNotesFg : nullptr);
-    m_theme["notification_bg"]  = Option("#333", "VALUE", ui ? ui->pushButtonColorNotificationBg : nullptr);
+    m_theme["bg"]        = Option(defaultColorVarBase, "VALUE", ui ? ui->pushButtonColorBg : nullptr);
+    m_theme["edit_bg"]   = Option(defaultColorVarBase, "VALUE", ui ? ui->pushButtonColorEditorBg : nullptr);
+    m_theme["fg"]        = Option(defaultColorVarText, "VALUE", ui ? ui->pushButtonColorFg : nullptr);
+    m_theme["edit_fg"]   = Option(defaultColorVarText, "VALUE", ui ? ui->pushButtonColorEditorFg : nullptr);
+    m_theme["num_fg"]    = Option(defaultColorVarPlaceholderText, "VALUE", ui ? ui->pushButtonColorNumberFg : nullptr);
+    m_theme["alt_bg"]    = Option(defaultColorVarAlternateBase, "VALUE", ui ? ui->pushButtonColorAltBg : nullptr);
+    m_theme["sel_bg"]    = Option(defaultColorVarHighlight, "VALUE", ui ? ui->pushButtonColorSelBg : nullptr);
+    m_theme["sel_fg"]    = Option(defaultColorVarHighlightText, "VALUE", ui ? ui->pushButtonColorSelFg : nullptr);
+    m_theme["find_bg"]   = Option("#ff0", "VALUE", ui ? ui->pushButtonColorFoundBg : nullptr);
+    m_theme["find_fg"]   = Option("#000", "VALUE", ui ? ui->pushButtonColorFoundFg : nullptr);
+    m_theme["notes_bg"]  = Option(defaultColorVarToolTipBase, "VALUE", ui ? ui->pushButtonColorNotesBg : nullptr);
+    m_theme["notes_fg"]  = Option(defaultColorVarToolTipText, "VALUE", ui ? ui->pushButtonColorNotesFg : nullptr);
     m_theme["notification_fg"]  = Option("#ddd", "VALUE", ui ? ui->pushButtonColorNotificationFg : nullptr);
 
     m_theme["font"]        = Option("", "VALUE", ui ? ui->pushButtonFont : nullptr);
@@ -368,7 +412,6 @@ void Theme::resetTheme()
     m_theme["find_font"]   = Option("", "VALUE", ui ? ui->pushButtonFoundFont : nullptr);
     m_theme["num_font"]    = Option("", "VALUE", ui ? ui->pushButtonNumberFont : nullptr);
     m_theme["notes_font"]  = Option("", "VALUE", ui ? ui->pushButtonNotesFont : nullptr);
-    m_theme["notification_font"]  = Option("", "VALUE", ui ? ui->pushButtonNotificationFont : nullptr);
     m_theme["show_number"] = Option(true, "checked", ui ? ui->checkBoxShowNumber : nullptr);
     m_theme["show_scrollbars"] = Option(true, "checked", ui ? ui->checkBoxScrollbars : nullptr);
 
@@ -484,7 +527,6 @@ void Theme::resetTheme()
 
     m_theme["css_template_items"] = Option("items");
     m_theme["css_template_main_window"] = Option("main_window");
-    m_theme["css_template_notification"] = Option("notification");
     m_theme["css_template_tooltip"] = Option("tooltip");
 }
 
@@ -507,7 +549,7 @@ void Theme::updateTheme()
     m_showRowNumber = value("show_number").toBool();
     m_rowNumberPalette.setColor(QPalette::Text, color("num_fg"));
     m_rowNumberFont = font("num_font");
-    m_rowNumberSize = QFontMetrics(m_rowNumberFont).boundingRect( QString("0123") ).size()
+    m_rowNumberSize = QFontMetrics(m_rowNumberFont).boundingRect( QLatin1String("0123") ).size()
             + QSize(m_margins.width(), m_margins.height());
 
     m_antialiasing = value("font_antialiasing").toBool();
@@ -540,8 +582,7 @@ QString Theme::getStyleSheet(const QString &name, Values values, int maxRecursio
     QFile file(fileName);
     if ( !file.open(QIODevice::ReadOnly) ) {
         log( QString("Failed to open stylesheet \"%1\": %2")
-             .arg(fileName)
-             .arg(file.errorString()), LogError );
+             .arg(fileName, file.errorString()), LogError );
         return QString();
     }
 
@@ -557,17 +598,17 @@ QString Theme::parseStyleSheet(const QString &css, Values values, int maxRecursi
     for ( int i = 0; i < css.size(); ++i ) {
         const int a = css.indexOf(variableBegin, i);
         if (a == -1) {
-            output.append(css.mid(i));
+            output.append(css.midRef(i));
             break;
         }
 
         const int b = css.indexOf(variableEnd, a + variableBegin.size());
         if (b == -1) {
-            output.append(css.mid(i));
+            output.append(css.midRef(i));
             break;
         }
 
-        output.append(css.mid(i, a - i));
+        output.append(css.midRef(i, a - i));
         i = b + variableEnd.size() - 1;
 
         const QString name = css
@@ -642,7 +683,7 @@ QString serializeColor(const QColor &color)
     if (color.alpha() == 255)
         return color.name();
 
-    return QString("rgba(%1,%2,%3,%4)")
+    return QString::fromLatin1("rgba(%1,%2,%3,%4)")
             .arg(color.red())
             .arg(color.green())
             .arg(color.blue())
@@ -653,7 +694,7 @@ QColor deserializeColor(const QString &colorName)
 {
     QColor color;
 
-    if ( colorName.startsWith("rgba(") ) {
+    if ( colorName.startsWith(QStringLiteral("rgba(")) ) {
         QStringList list = colorName.mid(5, colorName.indexOf(')') - 5).split(',');
         int r = list.value(0).toInt();
         int g = list.value(1).toInt();
@@ -661,6 +702,9 @@ QColor deserializeColor(const QString &colorName)
         int a = static_cast<int>( list.value(3).toDouble() * 255 );
 
         color = QColor(r, g, b, a > 255 ? a / 255 : a);
+    } else if ( colorName.startsWith(QStringLiteral("default_")) ) {
+        const QPalette::ColorRole role = defaultColorVarToRole(colorName);
+        color = QPalette().color(role);
     } else {
         color = QColor(colorName);
     }
